@@ -59,22 +59,22 @@ PotentialShapeType = int | np.ndarray | Sequence[int | Variable] | TensorVariabl
 
 
 __all__ = [
+    "CallableTensor",
+    "compile_pymc",
+    "cont_inputs",
+    "convert_data",
+    "convert_generator_data",
+    "convert_observed_data",
+    "floatX",
+    "generator",
     "gradient",
     "hessian",
     "hessian_diag",
     "inputvars",
-    "cont_inputs",
-    "floatX",
     "intX",
     "jacobian",
-    "CallableTensor",
     "join_nonshared_inputs",
     "make_shared_replacements",
-    "generator",
-    "convert_data",
-    "convert_generator_data",
-    "convert_observed_data",
-    "compile_pymc",
 ]
 
 
@@ -1024,7 +1024,12 @@ def compile_pymc(
     """
     # Create an update mapping of RandomVariable's RNG so that it is automatically
     # updated after every function call
-    rng_updates = collect_default_updates(inputs=inputs, outputs=outputs)
+    rng_updates = collect_default_updates(
+        inputs=[inp.variable if isinstance(inp, pytensor.In) else inp for inp in inputs],
+        outputs=[
+            out.variable if isinstance(out, pytensor.Out) else out for out in makeiter(outputs)
+        ],
+    )
 
     # We always reseed random variables as this provides RNGs with no chances of collision
     if rng_updates:
