@@ -88,7 +88,7 @@ from pymc.variational.minibatch_rv import MinibatchRandomVariable, get_scaling
 from pymc.variational.updates import adagrad_window
 from pymc.vartypes import discrete_types
 
-__all__ = ["ObjectiveFunction", "Operator", "TestFunction", "Group", "Approximation"]
+__all__ = ["Approximation", "Group", "ObjectiveFunction", "Operator", "TestFunction"]
 
 
 class VariationalInferenceError(Exception):
@@ -1450,7 +1450,7 @@ class Approximation(WithMemoization):
         """
         repl = collections.OrderedDict()
         # avoid scan if size is constant and equal to one
-        if isinstance(s, int) and (s == 1) or s is None:
+        if (isinstance(s, int) and (s == 1)) or s is None:
             repl[self.varlogp] = self.single_symbolic_varlogp
             repl[self.datalogp] = self.single_symbolic_datalogp
         return repl
@@ -1554,7 +1554,10 @@ class Approximation(WithMemoization):
         if random_seed is not None:
             (random_seed,) = _get_seeds_per_chain(random_seed, 1)
         samples: dict = self.sample_dict_fn(draws, random_seed=random_seed)
-        points = ({name: records[i] for name, records in samples.items()} for i in range(draws))
+        points = (
+            {name: np.asarray(records[i]) for name, records in samples.items()}
+            for i in range(draws)
+        )
 
         trace = NDArray(
             model=self.model,
