@@ -436,7 +436,7 @@ class TestModelWithDims(BaseModelGraphTest):
     model_func = model_with_dims
 
     def test_issue_6335_dims_containing_none(self):
-        with pm.Model(coords=dict(time=np.arange(5))) as pmodel:
+        with pm.Model(coords={"time": np.arange(5)}) as pmodel:
             data = pt.as_tensor(np.ones((3, 5)))
             pm.Deterministic("n", data, dims=(None, "time"))
 
@@ -561,17 +561,15 @@ def test_custom_node_formatting_graphviz(simple_model):
     }
 
     G = model_to_graphviz(simple_model, node_formatters=node_formatters)
-    body = set(item.strip() for item in G.body)
+    body = {item.strip() for item in G.body}
 
-    items = set(
-        [
-            "a [label=a]",
-            "b [label=b]",
-            "c [label=c]",
-            "a -> b",
-            "b -> c",
-        ]
-    )
+    items = {
+        "a [label=a]",
+        "b [label=b]",
+        "c [label=c]",
+        "a -> b",
+        "b -> c",
+    }
     assert body == items
 
 
